/*---------------------------------------------------------------------------
 * Name:    Blinky.c
 * Purpose: CMSIS RTOS2 LED flasher application
 *---------------------------------------------------------------------------*/

#include <stdio.h>
#include "cmsis_os2.h"                  /* ::CMSIS:RTOS2 */
#include "RTE_Components.h"             /* Component selection */
#include CMSIS_device_header

void app_main (void *argument);
static volatile uint32_t delay_val = 500U;
static osThreadId_t tid_thrLED;                /* Thread id of thread: LED */
static osThreadId_t tid_thrSIG;                /* Thread id of thread: SIG */

/*----------------------------------------------------------------------------
  Switch LED on
 *---------------------------------------------------------------------------*/
static void Switch_On (uint32_t led) {
  printf("LED On:  #%d\n\r", led);

#if defined LED_CONNECTED
  #if   defined S32K3xx_M7_0
    IP_SIUL2->GPDO180 = 1U;
  #elif defined S32K3xx_M7_1
    IP_SIUL2->GPDO92 = 1U;
  #endif
#endif
}

/*----------------------------------------------------------------------------
  Switch LED off
 *---------------------------------------------------------------------------*/
static void Switch_Off (uint32_t led) {
  printf("LED Off: #%d\n\r", led);

#if defined LED_CONNECTED
  #if   defined S32K3xx_M7_0
    IP_SIUL2->GPDO180 = 0U;
  #elif defined S32K3xx_M7_1
    IP_SIUL2->GPDO92 = 0U;
  #endif
#endif
}


/*----------------------------------------------------------------------------
  thrLED: blink LED
 *----------------------------------------------------------------------------*/
__NO_RETURN static void thrLED(void *argument) {
  uint32_t led_max    = 3U;
  uint32_t led_num    = 0U;

  (void)argument;

#if defined LED_CONNECTED
  #if   defined S32K3xx_M7_0
    IP_SIUL2->MSCR[180] = 0x00200000U;           /* enable output */
  #elif defined S32K3xx_M7_1
    IP_SIUL2->MSCR[92] = 0x00200000U;           /* enable output */
  #endif
#endif

  for (;;) {
    osThreadFlagsWait(0x0001U, osFlagsWaitAny ,osWaitForever);
    Switch_On (led_num);                                       /* Turn specified LED on */
    osThreadFlagsWait(0x0001U, osFlagsWaitAny ,osWaitForever);
    Switch_Off(led_num);                                       /* Turn specified LED off */

    led_num++;                                                 /* Change LED number */
    if (led_num >= led_max) {
      led_num = 0U;                                            /* Restart with first LED */
    }
  }

}

/*----------------------------------------------------------------------------
  thrSIG
 *----------------------------------------------------------------------------*/
__NO_RETURN static void thrSIG(void *argument) {

  (void)argument;

  for (;;) {
    osDelay(delay_val);                                        /* Wait */
    osThreadFlagsSet(tid_thrLED, 0x0001U);
  }

}

/*----------------------------------------------------------------------------
 * Application main thread
 *---------------------------------------------------------------------------*/
__NO_RETURN void app_main (void *argument) {

  (void)argument;

  tid_thrSIG = osThreadNew (thrSIG, NULL, NULL);               /* create SIG thread */
  if (tid_thrSIG == NULL) { /* add error handling */ }

  tid_thrLED = osThreadNew (thrLED, NULL, NULL);               /* create LED thread */
  if (tid_thrLED == NULL) { /* add error handling */ }

  osThreadExit();
}
