/* -----------------------------------------------------------------------------
 * Copyright (c) 2019 - 2021 ARM Ltd.
 *
 * This software is provided 'as-is', without any express or implied warranty.
 * In no event will the authors be held liable for any damages arising from
 * the use of this software. Permission is granted to anyone to use this
 * software for any purpose, including commercial applications, and to alter
 * it and redistribute it freely, subject to the following restrictions:
 *
 * 1. The origin of this software must not be misrepresented; you must not
 *    claim that you wrote the original software. If you use this software in
 *    a product, an acknowledgment in the product documentation would be
 *    appreciated but is not required.
 *
 * 2. Altered source versions must be plainly marked as such, and must not be
 *    misrepresented as being the original software.
 *
 * 3. This notice may not be removed or altered from any source distribution.
 *
 *
 * $Date:        01. October 2021
 * $Revision:    V1.1.0
 *
 * Project:      Flash Device Description for S32K3
 * --------------------------------------------------------------------------- */

/* History:
 *  Version 1.1.0
 *    Added S32K3x2 support
 *  Version 1.0.0
 *    Initial release
 */

#include "..\FlashOS.h"        /* FlashOS Structures */

extern struct FlashDevice const FlashDevice;

#if defined (S32K3_CODE)

#if defined (S32K3X2)
  struct FlashDevice const FlashDevice  =  {
    FLASH_DRV_VERS,                        /* Driver Version, do not modify! */
    "S32K3x2 2MB Code Flash (8KB Sector)",   /* Device Name */
    ONCHIP,                                /* Device Type */
    0x00400000,                            /* Device Start Address */
    0x001E0000,                            /* Device Size (2MB) without SBAF */
    0x00002000,                            /* Programming Page Size */
    0,                                     /* Reserved, must be 0 */
    0xFF,                                  /* Initial Content of Erased Memory */
   {0, 0, 0},                              /* padding bytes */
    1000,                                  /* Program Page Timeout 1000 mSec */
    3000,                                  /* Erase Sector Timeout 3000 mSec */

    /* Specify Size and Address of Sectors */
    {
      {0x00002000, 0x00000000},            /* Sector Size  8kB (256 Sectors) */
      {SECTOR_END            }
    }
  };
#endif /* S32K3X2 */

#if defined (S32K3X4)
  struct FlashDevice const FlashDevice  =  {
    FLASH_DRV_VERS,                        /* Driver Version, do not modify! */
    "S32K3x4 4MB Code Flash (8KB Sector)",   /* Device Name */
    ONCHIP,                                /* Device Type */
    0x00400000,                            /* Device Start Address */
    0x003E0000,                            /* Device Size (4MB) without SBAF */
    0x00002000,                            /* Programming Page Size */
    0,                                     /* Reserved, must be 0 */
    0xFF,                                  /* Initial Content of Erased Memory */
   {0, 0, 0},                              /* padding bytes */
    1000,                                  /* Program Page Timeout 1000 mSec */
    3000,                                  /* Erase Sector Timeout 3000 mSec */

    /* Specify Size and Address of Sectors */
    {
      {0x00002000, 0x00000000},            /* Sector Size  8kB (512 Sectors) */
      {SECTOR_END            }
    }
  };
#endif /* S32K3X4 */

#endif /* S32K3_CODE */


#if defined (S32K3_DATA)

#if defined (S32K3X2)
  struct FlashDevice const FlashDevice  =  {
    FLASH_DRV_VERS,                        /* Driver Version, do not modify! */
    "S32K3x2 128kB Data Flash (8KB Sector)", /* Device Name */
    ONCHIP,                                /* Device Type */
    0x10000000,                            /* Device Start Address */
    0x00020000,                            /* Device Size (128kB) */
    0x00002000,                            /* Programming Page Size */
    0,                                     /* Reserved, must be 0 */
    0xFF,                                  /* Initial Content of Erased Memory */
   {0, 0, 0},                              /* padding bytes */
    1000,                                  /* Program Page Timeout 1000 mSec */
    3000,                                  /* Erase Sector Timeout 3000 mSec */

    /* Specify Size and Address of Sectors */
    {
      {0x00002000, 0x00000000},            /* Sector Size  8kB (16 Sectors) */
      {SECTOR_END            }
    }
  };
#endif /* S32K3X2 */

#if defined (S32K3X4)
  struct FlashDevice const FlashDevice  =  {
    FLASH_DRV_VERS,                        /* Driver Version, do not modify! */
    "S32K3x4 128kB Data Flash (8KB Sector)", /* Device Name */
    ONCHIP,                                /* Device Type */
    0x10000000,                            /* Device Start Address */
    0x00020000,                            /* Device Size (128kB) */
    0x00002000,                            /* Programming Page Size */
    0,                                     /* Reserved, must be 0 */
    0xFF,                                  /* Initial Content of Erased Memory */
   {0, 0, 0},                              /* padding bytes */
    1000,                                  /* Program Page Timeout 1000 mSec */
    3000,                                  /* Erase Sector Timeout 3000 mSec */

    /* Specify Size and Address of Sectors */
    {
      {0x00002000, 0x00000000},            /* Sector Size  8kB (16 Sectors) */
      {SECTOR_END            }
    }
  };
#endif /* S32K3X4 */

#endif /* S32K3_DATA */
